pub enum StorageError {
Send(Box<dyn Error + Send>),
Receive,
Internal(Box<dyn Error + Send>),
}Expand description
An error occurring while storing or retrieving values from a database.
Variants
Send(Box<dyn Error + Send>)
Failed to send message to the storage manager.
Receive
Failed to receive result from the storage manager.
Internal(Box<dyn Error + Send>)
An error caused by the database, or some interaction with it.